@@ -244,7 +244,7 @@ class BaseModelView(BaseView):
         self.base_filters = self.base_filters or []
         self._base_filters = Filters().add_filter_list(self.datamodel, self.base_filters)
         list_cols = self.datamodel.get_columns_list()
-        self.search_columns = self.search_columns or list_cols
+        self.search_columns = self.search_columns or self.datamodel.get_search_columns_list()
         for col in list_cols:
             if not self.label_columns.get(col):
                 self.label_columns[col] = self._prettify_column(col)
@@ -275,9 +275,16 @@ class BaseCRUDView(BaseModelView):
     
     related_views = None
     """ 
-        List with instantiated GeneralView classes
-        That will be displayed related with this one using relationship sqlalchemy property
+        List with GeneralView classes
+        Will be displayed related with this one using relationship sqlalchemy property::
+
+            class MyView(GeneralView):
+                datamodel = SQLAModel(Group, db.session)
+                related_views = [MyOtherRelatedView]
+                
     """
+    _related_views = None
+    """ internal list with ref to instantiated view classes """
     list_title = ""
     """ List Title, if not configured the default is 'List ' with pretty model name """
     show_title = ""
@@ -427,6 +434,7 @@ class BaseCRUDView(BaseModelView):
 
     def _init_properties(self):
         self.related_views = self.related_views or []
+        self._related_views = self._related_views or []
         self.description_columns = self.description_columns or {}
         self.validators_columns = self.validators_columns or {}
         self.add_form_extra_fields = self.add_form_extra_fields or {}
@@ -480,7 +488,7 @@ class BaseCRUDView(BaseModelView):
                                 widgets = None, **args):
         widgets = widgets or {}
         widgets['related_lists'] = []
-        for view in self.related_views:
+        for view in self._related_views:
             if orders.get(view.__class__.__name__):
                 order_column, order_direction = orders.get(view.__class__.__name__)
             else: order_column, order_direction = '',''
