@@ -1,6 +1,10 @@
 # -*- coding: utf-8 -*-
-from itertools import groupby
 import calendar
+import sys
+import logging
+import sqlalchemy as sa
+
+from itertools import groupby
 from flask import flash
 from flask.ext.babelpkg import gettext, ngettext, lazy_gettext
 from sqlalchemy.orm import class_mapper, joinedload
@@ -8,11 +12,12 @@ from sqlalchemy.exc import IntegrityError
 from sqlalchemy import MetaData
 from sqlalchemy import func
 
-import sqlalchemy as sa
-import sys
+from group import GroupByDateYear, GroupByDateMonth, GroupByCol
+
 from mixins import FileColumn, ImageColumn
 from ..filemanager import FileManager, ImageManager
 
+log = logging.getLogger(__name__)
 
 class DataModel():
     obj = None
@@ -136,7 +141,6 @@ class SQLAModel(DataModel):
         
         return count, query.all()
 
-
     def query_simple_group(self, group_by = '', filters = None, order_column = '', order_direction = ''):
         if self.is_relation_col(group_by):
             rel_model, rel_direction = self._get_related_model(group_by)
@@ -155,19 +159,27 @@ class SQLAModel(DataModel):
         query = self.session.query(self.obj)
         query = self._get_base_query(query = query, filters = filters, order_column = group_by, order_direction = 'asc')
         query_result = query.all()
-        retlst = []
-        for ( grouped, items ) in groupby( query_result, lambda x: (getattr(x,group_by).month,getattr(x,group_by).year) ):
-            retlst.append([calendar.month_name[grouped[0]] + ' ' + str(grouped[1]), len(list(items))])
-        return retlst
-        
+        group = GroupByDateMonth(group_by,'Group by Month')
+        return group.apply(query_result)
+
+    """        
     def query_year_group(self, group_by = '', filters = None, order_column = '', order_direction = ''):
         query = self.session.query(self.obj)
         query = self._get_base_query(query = query, filters = filters, order_column = group_by, order_direction = 'asc')
         query_result = query.all()
+        log.debug("query_year_group %s" % (str(query_result)))
         retlst = []
         for ( grouped, items ) in groupby( query_result, lambda x: (getattr(x,group_by).year)):
             retlst.append([grouped, len(list(items))])
         return retlst
+    """
+
+    def query_year_group(self, group_by = '', filters = None, order_column = '', order_direction = ''):
+        query = self.session.query(self.obj)
+        query = self._get_base_query(query = query, filters = filters, order_column = group_by, order_direction = 'asc')
+        query_result = query.all()
+        group_year = GroupByDateYear(group_by,'Group by Year')
+        return group_year.apply(query_result)
 
     """
     -----------------------------------------
@@ -233,10 +245,12 @@ class SQLAModel(DataModel):
             return True
         except IntegrityError as e:
             flash(unicode(self.add_integrity_error_message),'warning')
+            log.warning("Add record integrity error")
             self.session.rollback()
             return False
         except:
             flash(unicode(self.general_error_message + ' '  + str(sys.exc_info()[0])),'danger')
+            log.exception("Add record error")
             self.session.rollback()
             return False
 
@@ -248,10 +262,12 @@ class SQLAModel(DataModel):
             return True
         except IntegrityError as e:
             flash(unicode(self.edit_integrity_error_message),'warning')
+            log.warning("Edit record integrity error")
             self.session.rollback()
             return False
         except:
             flash(unicode(self.general_error_message + ' '  + str(sys.exc_info()[0])),'danger')
+            log.exception("Edit record error")
             self.session.rollback()
             return False
                 
@@ -265,10 +281,12 @@ class SQLAModel(DataModel):
             return True
         except IntegrityError as e:
             flash(unicode(self.delete_integrity_error_message),'warning')
+            log.warning("Delete record integrity error")
             self.session.rollback()
             return False
         except:
             flash(unicode(self.general_error_message + ' '  + str(sys.exc_info()[0])),'danger')
+            log.exception("Delete record error")
             self.session.rollback()
             return False
                 
@@ -356,6 +374,20 @@ class SQLAModel(DataModel):
                 ret_lst.append(prop.key)
         return ret_lst
 
+    #TODO get diferent solution, more intergrated with filters
+    def get_search_columns_list(self):
+        ret_lst = []
+        for prop in self.get_properties_iterator():
+            if not self.is_relation(prop):
+                if (not self.is_pk(self.get_property_first_col(prop))) and (not self.is_fk(self.get_property_first_col(prop))):
+                    col = prop.key
+                    if (not self.is_image(col)) and (not self.is_file(col)):
+                        ret_lst.append(prop.key)
+            else:
+                    ret_lst.append(prop.key)
+        return ret_lst
+
+
     def get_order_columns_list(self):
         ret_lst = []
         for prop in self.get_properties_iterator():
