@@ -1,13 +1,15 @@
+import logging
 from flask.ext.babelpkg import lazy_gettext
 
+log = logging.getLogger(__name__)
+
 class BaseFilter(object):
 
     column_name = ''
     datamodel = None
     model = None
     name = ''
-    """ The filter display name """
-    
+
     def __init__(self, column_name, datamodel):
         """
             Constructor.
@@ -175,7 +177,7 @@ class Filters(object):
                     FilterSmaller(col, datamodel),
                     FilterNotEqual(col, datamodel)]
             else:
-                print "Filter type not supported for column: %s" % (col)
+                log.warning('Filter type not supported for column: %s' % (col))
                 return None
 
     def clear_filters(self):
